.. _dobble_variantes:

Variantes
=========

Je proposerai ici deux variantes du jeu de Dobble, pas forcément jouables, mais
qui peuvent être intéressantes du point de vue mathématique.

Diffle
------

TODO

Mémobble
--------

TODO
